_`umbra.ui.common`
==================

.. automodule:: umbra.ui.common

Module Attributes
-----------------

.. attribute:: umbra.ui.common.LOGGER

Functions
---------

.. autofunction:: getApplicationInstance

.. autofunction:: parseLocation

.. autofunction:: getResourcePath

.. autofunction:: setWindowDefaultIcon

.. autofunction:: getSectionsFileParser

.. autofunction:: storeLastBrowsedPath

.. autofunction:: getQVariantAsString

.. autofunction:: parentsWalker

.. autofunction:: signalsBlocker

.. autofunction:: showWaitCursor

.. autofunction:: setToolBoxHeight

Classes
-------

.. autoclass:: Location
	:show-inheritance:
	:members:

